autowisp.database.data_model.provenance.observer module — AutoWISP documentation

# autowisp.database.data_model.provenance.observer module

## Class Inheritance Diagram

Define the observer dataset table for the pipeline

class autowisp.database.data_model.provenance.observer.Observer(**kwargs)

  Bases: `DataModelBase`

  The table describing the observers

  __str__()

    Human readable string identifying the observer.

  cameras
  email

    The email of the observer

  id

    A unique identifier for each row.

  mounts
  name

    The name of the observer

  notes

    Any user supplied notes describing the observer.

  observing_sessions
  phone

    The phone number of the observer

  telescopes
  timestamp

    When record was last changed